The Dynamic Time Warping (DTW) distance for time series allows non-linear alignments of time series to match similar patterns in time series of different lengths and or different speeds. Beside the traditional implementation of the DTW algorithm, the specialties of this package are, (1) the incremental calculation, which is specifically useful for life data streams due to computationally efficiency, (2) the vector based implementation of the traditional DTW algorithm which is faster because no matrices are allocated and is especially useful for computing distance matrices of pairwise DTW distances for many time series and (3) the combination of incremental and vector-based calculation.
Main features:
Detect k-nearest subsequences in longer time series, rundtw
Matrix-based dtw and Vector-based dtw2vec implementation of the DTW algorithm
Sakoe Chiba warping window
Early abandoning and lower bounding
Support for multivariate time series
Fast calculation of a distance matrix of pairwise DTW distances for clustering or classification of many multivariate time series, dtw_dismat
Aggregate cluster members with dba or get the centroid with centroid
C++ in the heart thanks to Rcpp
Dynamic programming algorithm optimization for spoken word recognition by Sakoe and Chiba published in 1978 (DOI:10.1109/TASSP.1978.1163055)
https://ieeexplore.ieee.org/document/1163055/