The Dynamic Time Warping (DTW) distance for time series allows non-linear alignments of time series to match similar patterns in time series of different lengths and or different speeds. Beside the traditional implementation of the DTW algorithm, the specialties of this package are, (1) the incremental calculation, which is specifically useful for life data streams due to computationally efficiency, (2) the vector based implementation of the traditional DTW algorithm which is faster because no matrices are allocated and is especially useful for computing distance matrices of pairwise DTW distances for many time series and (3) the combination of incremental and vector-based calculation.
Main features:
C++ in the heart thanks to Rcpp
Incremental Calculation, idtw() and idtw2vec()
Matrix-based dtw() and Vector-based dtw2vec() implementation of the DTW algorithm
Sakoe Chiba Warping Window
Early abandoning
support for multivariate time series
distDTW() for fast calculation of a Distance Matrix of pairwise DTW distances for clustering or classification of many multivariate time series
DBA() for averaging a centroid of a found cluster
Dynamic programming algorithm optimization for spoken word recognition by Sakoe and Chiba published in 1978 (DOI:10.1109/TASSP.1978.1163055)
https://ieeexplore.ieee.org/document/1163055/