character, describes the method of to normalize the time series (per column if x is multivariate). The parameter type is either 'z' for z-normalization or '01' for max-min normalization.
xmean
mean used for z-normalization
xsd
standard deviation used for z-normalization
xmin
minimum used for 0-1 normalization
xmax
maximum used for 0-1 normalization
Value
x
the normalized vector
Details
For a vector x the z-normalization subtracts the mean and devides by the standard deviation: of (x-mean(x))/sd(x). The min-max normalization performs (x-min(x))/(max(x)-min(x)).