Plot function for objects of type dba, the output of DBA().
# S3 method for dba
plot(x, type = c("barycenter", "m2m", "m2lot"), ...)
# an alias for plot_idtw
plot_dba(x, type = c("barycenter", "m2m", "m2lot"), ...)plotBary(x, ...)
plotM2m(x, ...)
plotM2lot(x, ...)
output from DBA()
character, one of c('barycenter', 'm2m', 'm2lot')
Other arguments passed on to methods. Not currently used.
'barycenter' plots the iterations of the barycenter per dimension.
'm2m' plots the distances (distance method set by iter_dist_method, see DBA) of one barycenter-iteration to the former iteration step.
'm2lot' plots the distances (if step_pattern == 'symmetric2' the normalized distances are plotted) of the barycenter to the list of time series per iteration.
DBA